@@ -49,12 +49,14 @@ public:
     QDBusServiceWatcher watcher;
     OrgFreedesktopNetworkManagerInterface iface;
     uint nmState;
+    uint m_connectivity;
+    bool m_isNetworkingEnabled;
+    bool m_isWimaxEnabled;
+    bool m_isWimaxHardwareEnabled;
     bool m_isWirelessEnabled;
     bool m_isWirelessHardwareEnabled;
     bool m_isWwanEnabled;
     bool m_isWwanHardwareEnabled;
-    bool m_isWimaxEnabled;
-    bool m_isWimaxHardwareEnabled;
     QString m_version;
 
     // to store NetworkManager's version.
@@ -65,7 +67,6 @@ public:
     int compareVersion(const QString &version);
     int compareVersion(const int x, const int y, const int z) const;
 
-    bool m_isNetworkingEnabled;
     QMap<QString, ActiveConnection::Ptr> m_activeConnections;
     ActiveConnection::Ptr findRegisteredActiveConnection(const QString &);
     // manage device children
@@ -99,6 +100,10 @@ public:
     void sleep(bool sleep);
     void setLogging(NetworkManager::LogLevel, NetworkManager::LogDomains);
     NMStringMap permissions();
+    Connectivity connectivity() const;
+    QDBusPendingReply<uint> checkConnectivity();
+    ActiveConnection::Ptr primaryConnection();
+    ActiveConnection::Ptr activatingConnection();
 protected Q_SLOTS:
     void init();
     void onDeviceAdded(const QDBusObjectPath &state);
@@ -107,7 +112,9 @@ protected Q_SLOTS:
     void daemonRegistered();
     void daemonUnregistered();
 private:
+    void connectivityChanged(uint connectivity);
     void stateChanged(uint state);
+    static NetworkManager::Connectivity convertConnectivity(uint connectivity);
     static NetworkManager::Status convertNMState(uint state);
 
 };
